PathwayProjection
=================

.. container:: subclasses

    *Subclasses*

    .. toctree::
       :maxdepth: 1

       MappingProjection
       MaskedMappingProjection
       AutoAssociativeProjection

.. automodule:: psyneulink.core.components.projections.pathway.pathwayprojection
   :members:
   :private-members:
   :exclude-members: PathwayProjection_Base, Linear, random, Parameters
